## Iris flower data

### Input x

4 flower measurements (continuous covariates):

1. Sepal length
2. Sepal width
3. Petal length
4. Petal width

### Output y

Flower species (categorical variable with 3 levels).

| Value | Species    |
| ----- | ---------- |
| 0     | Setosa     |
| 1     | Versicolor |
| 2     | Virginica  |

### Number of samples

150 flowers, 50 from each of the 3 species.

### References

- Anderson, Edgar. "The species problem in Iris." *Annals of the Missouri Botanical Garden* 23.3 (1936): 457-509.
- Fisher, Ronald A. "The use of multiple measurements in taxonomic problems." *Annals of eugenics* 7.2 (1936): 179-188.
